diff --git a/build.gradle b/build.gradle
index 0fe4af4..cf3e588 100644
--- a/build.gradle
+++ b/build.gradle
@@ -48,6 +48,10 @@ allprojects {
 				excludeGroupByRegex "io.github.llamalad7"
 			}
 		}
+		maven {
+			url "https://oss.sonatype.org/content/repositories/snapshots"
+		}
+		mavenLocal()
 	}
 
 	dependencies {
@@ -120,6 +124,10 @@ dependencies {
 
 	development "io.github.llamalad7:mixinextras-fabric:$mixin_extras_version"
 
+	api "pro.gravit.launcher:launcher-core:5.6.0-SNAPSHOT"
+	api "pro.gravit.launcher:launcher-ws-api:5.6.0-SNAPSHOT"
+	api "pro.gravit.launcher:launcher-client-api:5.6.0-SNAPSHOT"
+
 	testCompileOnly 'org.jetbrains:annotations:23.0.0'
 
 	// Unit testing for mod metadata
diff --git a/src/main/java/net/fabricmc/loader/impl/launch/knot/KnotClassDelegate.java b/src/main/java/net/fabricmc/loader/impl/launch/knot/KnotClassDelegate.java
index 0b7c38e..d2c075e 100644
--- a/src/main/java/net/fabricmc/loader/impl/launch/knot/KnotClassDelegate.java
+++ b/src/main/java/net/fabricmc/loader/impl/launch/knot/KnotClassDelegate.java
@@ -214,6 +214,8 @@ final class KnotClassDelegate<T extends ClassLoader & ClassLoaderAccess> impleme
 			if (c == null) {
 				if (name.startsWith("java.")) { // fast path for java.** (can only be loaded by the platform CL anyway)
 					c = PLATFORM_CLASS_LOADER.loadClass(name);
+				} else if (name.startsWith("pro.gravit.launcher.") || name.startsWith("pro.gravit.utils.")) { // launcher
+					c = KnotClassDelegate.class.getClassLoader().loadClass(name);
 				} else {
 					c = tryLoadClass(name, false); // try local load
 
diff --git a/src/main/java/net/fabricmc/loader/impl/launch/knot/KnotClassLoader.java b/src/main/java/net/fabricmc/loader/impl/launch/knot/KnotClassLoader.java
index 4771ce1..c1a6e1d 100644
--- a/src/main/java/net/fabricmc/loader/impl/launch/knot/KnotClassLoader.java
+++ b/src/main/java/net/fabricmc/loader/impl/launch/knot/KnotClassLoader.java
@@ -25,6 +25,8 @@ import java.security.SecureClassLoader;
 import java.util.Enumeration;
 import java.util.Objects;
 
+import pro.gravit.launcher.base.api.ClientService;
+
 import net.fabricmc.api.EnvType;
 import net.fabricmc.loader.impl.game.GameProvider;
 import net.fabricmc.loader.impl.launch.knot.KnotClassDelegate.ClassLoaderAccess;
@@ -124,6 +126,11 @@ final class KnotClassLoader extends SecureClassLoader implements ClassLoaderAcce
 		return delegate.tryLoadClass(name, false);
 	}
 
+	@Override
+	protected String findLibrary(String libname) {
+		return ClientService.findLibrary(libname);
+	}
+
 	@Override
 	public void addUrlFwd(URL url) {
 		urlLoader.addURL(url);
